%%%%%%%%% Model ARX for balancing price %%%%%%%%

function prediction = model_ARX_RB(data, model)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % data - matrix with explanatory and exogenous variables
    % model - use one of nine different models:
        % '1' - X1,X2,X3, L =[2,7]
        % '2' - X1,X2,X3, L = [2]
        % '3' - X2,X3, L = [2,7]
        % '4' - X2,X3, L =[2]
        % '5' - L =[2,7]
        % '6' - L =[2]
        % '7' - X1,X2,X3, L =[2,...,7]
        % '8' -  L =[2,...,7]
        % '9' - X2,X3, L =[2,...,7]
    % X1 - Forecast of energy generation
    % X2 - Forecast of wind generation
    % X3 - Forecast of reserves
    % X4 - Imbalance
    % X5 - Co2
    % X6 - Gas
    % X7 - Temperature
     
   
    % Matrix of prediction prices
    prediction = zeros(24,1);
    
     % Building a model for each hour separately
    for hour = 1:24
        % "Price" - vector of prices for each hour separately
        price = data(hour:24:end-24,4);
        
        % Minimum of the previous day
        price_min = data(hour:24:end-24,18);
        
        % Maximum of the previous day
        price_max = data(hour:24:end-24,19);
        
        % Prices of RDN
        price_RDN = data(hour:24:end-24,3);   
        
         % Minimum of the previous day of RDN market
        price_RDN_min = data(hour:24:end-24,16); 
        
        % Maximum of the previous day of RDN market
        price_RDN_max = data(hour:24:end-24,17); 
        
        % Forecast of generation
        generation = data(hour:24:end,6);
        
        % Forecast of wind generation
        wind = data(hour:24:end,7);
        
        % Forecast of load
        load = data(hour:24:end,5);
        
        % Forecast of solar
        solar = data(hour:24:end,8);
        
        % Co2
        Co2 = data(hour:24:end-24,10);
        
        % Gas
        gas = data(hour:24:end-24,9);
        
        % Dummies
        D_Sat = data(hour:24:end,12);
        D_Sun = data(hour:24:end,13);
        D_Mon = data(hour:24:end,14);
        D_rest = data(hour:24:end,15);
       
        Y = price(8:end);
        
        % Model '1' - X1,X2,X3,X4,X5,X6, L =[2,7]
        if model == '1'  
            % Matrix X in ARX's model
            X = [price_RDN(7:end-1),price(6:end-2),price(1:end-7),generation(8:end-1),wind(8:end-1),load(8:end-1),...
                solar(8:end-1),Co2(7:end-1),gas(7:end-1),...
                price_RDN_min(7:end-1),price_RDN_max(7:end-1),...
                D_Sat(8:end-1),D_Sun(8:end-1),D_Mon(8:end-1),D_rest(8:end-1)];
           % X = [ones(size(price_RDN(7:end-1))),X];
            % Prediction on d+1 day
            X_reg = [price_RDN(end), price(end-1),price(end-6),generation(end), wind(end),load(end),...
                solar(end), Co2(end),gas(end),...
                price_RDN_min(end),price_RDN_max(end),...
                D_Sat(end),D_Sun(end),D_Mon(end), D_rest(end)];
           % X_reg = [ones(size(price_RDN(end))),X_reg];
        
        % Model '2'- X1,X2,X3,X4,X5,X6,X7, L = [2]
        elseif model == '2'
            % Matrix X in ARX's model
            X = [price_RDN(7:end-1),price(6:end-2),generation(8:end-1),wind(8:end-1),load(8:end-1),...
                solar(8:end-1),Co2(7:end-1),gas(7:end-1),...
                price_RDN_min(7:end-1),price_RDN_max(7:end-1),...
                D_Sat(8:end-1),D_Sun(8:end-1), D_Mon(8:end-1),D_rest(8:end-1)];
            % Prediction on d+1 day
            X_reg = [price_RDN(end), price(end-1),generation(end), wind(end),load(end),...
                solar(end), Co2(end),gas(end),...
                price_RDN_min(end),price_RDN_max(end),...
                D_Sat(end),D_Sun(end),D_Mon(end),D_rest(end)];
        
        % Model '3'- X2,X3,X4,X6, L = [2,7]
        elseif model == '3'
            % Matrix X in ARX's model
            X = [price_RDN(7:end-1),price(6:end-2),price(1:end-7),wind(8:end-1),load(8:end-1),...
                solar(8:end-1), gas(7:end-1),...
                price_RDN_min(7:end-1),price_RDN_max(7:end-1),...
                D_Sat(8:end-1),D_Sun(8:end-1),D_Mon(8:end-1),D_rest(8:end-1)];
            % Prediction on d+1 day
            X_reg = [price_RDN(end), price(end-1),price(end-6),wind(end),load(end),...
                solar(end), gas(end),...
                price_RDN_min(end),price_RDN_max(end),...
                D_Sat(end),D_Sun(end),D_Mon(end),D_rest(end)];
         
        % Model '4'- X2,X3,X4,X6, L =[2]
        elseif model == '4'
             % Matrix X in ARX's model
            X = [price_RDN(7:end-1),price(6:end-2),wind(8:end-1),load(8:end-1),...
                solar(8:end-1), gas(7:end-1),...
                price_RDN_min(7:end-1),price_RDN_max(7:end-1),...
                D_Sat(8:end-1),D_Sun(8:end-1),D_Mon(8:end-1),D_rest(8:end-1)];
            % Prediction on d+1 day
            X_reg = [price_RDN(end), price(end-1),wind(end),load(end),...
                solar(end), gas(end),...
                price_RDN_min(end),price_RDN_max(end),...
                D_Sat(end),D_Sun(end),D_Mon(end),D_rest(end)];
        
            %                 
            %                 
        % Model '5' - X1,X2,X3, L =[2,7]
        elseif model == '5'
              % Matrix X in ARX's model
            X = [price_RDN(7:end-1),price(6:end-2),price(1:end-7),...
                generation(8:end-1),wind(8:end-1),load(8:end-1),...
                price_RDN_min(7:end-1),price_RDN_max(7:end-1),...
                D_Sat(8:end-1),D_Sun(8:end-1),D_Mon(8:end-1),D_rest(8:end-1)];
            % Prediction on d+1 day
            X_reg = [price_RDN(end), price(end-1),price(end-6),...
                generation(end), wind(end),load(end),...
                price_RDN_min(end),price_RDN_max(end),...
                D_Sat(end),D_Sun(end),D_Mon(end),D_rest(end)];
       
        % Model '6' - X1,X2,X3, L =[2]
        elseif model == '6'
             % Matrix X in ARX's model
            X = [price_RDN(7:end-1),price(6:end-2),...
                generation(8:end-1),wind(8:end-1),load(8:end-1),...
                price_RDN_min(7:end-1),price_RDN_max(7:end-1),...
                D_Sat(8:end-1),D_Sun(8:end-1),D_Mon(8:end-1),D_rest(8:end-1)];
            % Prediction on d+1 day
            X_reg = [price_RDN(end), price(end-1),...
                generation(end), wind(end),load(end),...
                price_RDN_min(end),price_RDN_max(end),...
                D_Sat(end),D_Sun(end),D_Mon(end),D_rest(end)];
        
        % Model '7' - X1,X2,X3,X4,X5,X6,X7, L =[2,...,7]
        elseif model == '7'
             % Matrix X in ARX's model
            X = [price_RDN(7:end-1),price(6:end-2),price(5:end-3),price(4:end-4),price(3:end-5),price(2:end-6),price(1:end-7),...
                generation(8:end-1),wind(8:end-1),load(8:end-1),...
                solar(8:end-1),Co2(7:end-1),gas(7:end-1),...
                price_RDN_min(7:end-1),price_RDN_max(7:end-1),...
                D_Sat(8:end-1),D_Sun(8:end-1),D_Mon(8:end-1),D_rest(8:end-1)];
            % Prediction on d+1 day
            X_reg = [price_RDN(end), price(end-1),price(end-2),price(end-3),price(end-4),price(end-5),price(end-6),...
                generation(end), wind(end),load(end),...
                solar(end), Co2(end),gas(end),...
                price_RDN_min(end),price_RDN_max(end),...
                D_Sat(end),D_Sun(end),D_Mon(end),D_rest(end)];
        
        % Model '8' - L =[2,...,7]
        elseif model == '8'
             % Matrix X in ARX's model
            X = [price_RDN(7:end-1),price(6:end-2),price(5:end-3),price(4:end-4),price(3:end-5),price(2:end-6),price(1:end-7),...
                price_RDN_min(7:end-1),price_RDN_max(7:end-1),...
                D_Sat(8:end-1),D_Sun(8:end-1),D_Mon(8:end-1),D_rest(8:end-1)];
            % Prediction on d+1 day
            X_reg = [price_RDN(end), price(end-1),price(end-2),price(end-3),price(end-4),price(end-5),price(end-6),...
                price_RDN_min(end),price_RDN_max(end),...
                D_Sat(end),D_Sun(end),D_Mon(end),D_rest(end)];
        
        % Model '9' - X2,X3,X4,X6, L =[2,...,7]
        elseif model == '9'
             % Matrix X in ARX's model
            X = [price_RDN(7:end-1),price(6:end-2),price(5:end-3),price(4:end-4),price(3:end-5),price(2:end-6),price(1:end-7),...
                wind(8:end-1),load(8:end-1),...
                solar(8:end-1), gas(7:end-1),...
                price_RDN_min(7:end-1),price_RDN_max(7:end-1),...
                D_Sat(8:end-1),D_Sun(8:end-1),D_Mon(8:end-1),D_rest(8:end-1)];
            % Prediction on d+1 day
            X_reg = [price_RDN(end), price(end-1),price(end-2),price(end-3),price(end-4),price(end-5),price(end-6),...
                wind(end),load(end),...
                solar(end), gas(end),...
                price_RDN_min(end),price_RDN_max(end),...
                D_Sat(end),D_Sun(end),D_Mon(end),D_rest(end)];
        end
        
        beta = regress(Y,X);
        price_point = X_reg*beta;
        prediction(hour,1) = price_point;
    end
end