function final_weights = optimal_scenarios_measure(prediction_QRA_RB, prediction_QRA_RDN,amount_day_3, nr_U, option, measure)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % prediction_QRA_RB - prediction prices using quantile regression method for the day ahead market
    % prediction_QRA_RDN - prediction prices using quantile regression method for the complementary market
    % amount_day_3 - amount of day in validation's window 
    % nr_U - number of scenarios 
    % option - method of finding value of w_ht, which maximalize s_ht 
    % measure - measure of risk
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%% Create different scenarios (optimization of selling strategy) %%%%%%
    
    [price_scenario_RB, price_scenario_RDN] = interpolation_quantile_regression_RDN_RB(prediction_QRA_RB, prediction_QRA_RDN, amount_day_3, nr_U);
    
    U = rand(1,nr_U);
    weights = 0:0.1:1;

    weights_end_05 = zeros(1,amount_day_3*24);
    weights_end_95 = zeros(1,amount_day_3*24);

    for k = 1:amount_day_3*24
        scenario_h_t = zeros(length(weights),length(U));
        quantile_weights_05 = zeros(1,length(weights));
        quantile_weights_95 = zeros(1,length(weights));
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %%%%%%%%%%%%%%%%%%%%%%%%% VOLATILITY: 'std'%%%%%%%%%%%%%%%%%%%%%%%
        % In case of volatility we want to minimize the risk, so both weights: 
        % 'weights_end_05' and 'weights_end_95' are the same. We minimize
        % the function 'quantile_weight'. 
        switch measure  
            case 'std'
                for i = 1 :length(weights)
                    for j = 1 :length(U)  
                        scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                    end
                    quantile_weights_05(i) = std(scenario_h_t(i,:));
                    quantile_weights_95(i) = std(scenario_h_t(i,:));
                end
                index_weights_05 = find(quantile_weights_05 == min(quantile_weights_05));
                index_weights_95 = find(quantile_weights_95 == min(quantile_weights_95));
                weight_start_05 = weights(index_weights_05);  % chosen the best weight
                weight_start_95 = weights(index_weights_95);
            
           if option == '1' 
                fun_05 = @(weights)quantile_weight(weights, price_scenario_RB, price_scenario_RDN,0.05, k, nr_U,measure);
                fun_95 = @(weights)quantile_weight(weights, price_scenario_RB, price_scenario_RDN,0.95, k, nr_U,measure);
                lb = 0;
                ub = 1;
                A = [];
                b = [];
                Aeq = [];
                beq = [];
                options = optimoptions('fmincon','Display','off');
                w_05 = fmincon(fun_05,weight_start_05,A,b,Aeq,beq,lb,ub,[],options);
                w_95 = fmincon(fun_95,weight_start_95,A,b,Aeq,beq,lb,ub,[],options);
                weights_end_05(k) = w_05;
                weights_end_95(k) = w_95;
           end
        end

        % Chosing the other measure
        switch measure
            case 'quantile'
                for i = 1 :length(weights)
                    for j = 1 :length(U)  
                        scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                    end
                    quantile_weights_05(i) = quantile(scenario_h_t(i,:),0.05);  
                    quantile_weights_95(i) = quantile(scenario_h_t(i,:),0.95);
                end
            case 'expectiles'
                for i = 1 :length(weights)
                    for j = 1 :length(U) 
                        scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                    end
                    quantile_weights_05(i) = expectile(scenario_h_t(i,:),0.05);  
                    quantile_weights_95(i) = expectile(scenario_h_t(i,:),0.95);
                end
            case 'ES'
                for i = 1 :length(weights)
                    for j = 1 :length(U)  
                        scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                    end
                    VaR_05 = quantile(scenario_h_t(i,:),0.05);
                    VaR_95 = quantile(scenario_h_t(i,:),0.95);
                    index_05 = find(scenario_h_t(i,:) < VaR_05);
                    index_95 = find(scenario_h_t(i,:) > VaR_95);
                    help_vec_05 = zeros(1,length(index_05));
                    help_vec_95 = zeros(1,length(index_95));
                    for z = 1:length(index_05)
                        help_vec_05(z) = scenario_h_t(i,index_05(z));
                    end
                    for z = 1:length(index_95)
                        help_vec_95(z) = scenario_h_t(i,index_95(z));
                    end
                    quantile_weights_05(i) =  mean(help_vec_05);
                    quantile_weights_95(i) =  mean(help_vec_95);    
                end
            % In case of sharpe ration, median/IQR, q_95/q_5, we consider only the
            % case when we have an optimal strategy, so both weights: 
            % 'weights_end_05' and 'weights_end_95' are the same.
             case 'sharpe'
                for i = 1 :length(weights)
                    for j = 1 :length(U)  
                        scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                    end
                    quantile_weights_05(i) = mean(scenario_h_t(i,:))/std(scenario_h_t(i,:));  
                    quantile_weights_95(i) = mean(scenario_h_t(i,:))/std(scenario_h_t(i,:));
                end
             
             case 'q_50_IQR'
                for i = 1 :length(weights)
                    for j = 1 :length(U) 
                        scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                    end
                    quantile_weights_05(i) = quantile(scenario_h_t(i,:),0.5)/iqr(scenario_h_t(i,:));  
                    quantile_weights_95(i) = quantile(scenario_h_t(i,:),0.5)/iqr(scenario_h_t(i,:));  
                end
                
             case 'median'
                for i = 1 :length(weights)
                    for j = 1 :length(U)  
                        scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                    end
                    quantile_weights_05(i) = quantile(scenario_h_t(i,:),0.5); 
                    quantile_weights_95(i) = median(scenario_h_t(i,:));
                end
                
             case 'mean'
                for i = 1 :length(weights)
                    for j = 1 :length(U) 
                        scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                    end
                    quantile_weights_05(i) = mean(scenario_h_t(i,:));
                    quantile_weights_95(i) = mean(scenario_h_t(i,:));
                end
                
        end
        
        switch measure
            case {'quantile', 'expectiles', 'ES', 'sharpe', 'q_50_IQR','median','mean'}
     
                % looking for a index, where the value of quantile is maximal
                index_weights_05 = find(quantile_weights_05 == max(quantile_weights_05));
                index_weights_95 = find(quantile_weights_95 == max(quantile_weights_95));
                weight_start_05 = weights(index_weights_05);  % chosen the best weight
                weight_start_95 = weights(index_weights_95);

                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                %%%%%%%%%% Looking for value of w_ht, which maximalize s_ht %%%%%%%%%%

                if option == '1' % The first way
                    fun_05 = @(weights)-quantile_weight(weights, price_scenario_RB, price_scenario_RDN,0.05, k,nr_U, measure);
                    fun_95 = @(weights)-quantile_weight(weights, price_scenario_RB, price_scenario_RDN,0.95, k,nr_U, measure);
                    lb = 0;
                    ub = 1;
                    A = [];
                    b = [];
                    Aeq = [];
                    beq = [];
                    options = optimoptions('fmincon','Display','off');
                    w_05 = fmincon(fun_05,weight_start_05,A,b,Aeq,beq,lb,ub,[],options);
                    w_95 = fmincon(fun_95,weight_start_95,A,b,Aeq,beq,lb,ub,[],options);
                    weights_end_05(k) = w_05;
                    weights_end_95(k) = w_95;

                elseif option == '2'  % The second way
                    % fit the curve to data
                    fit_curve_05 = polyfit(weights, quantile_weights_05, 1);
                    fit_curve_95 = polyfit(weights, quantile_weights_95, 1);

                    % looking for value of w_ht, which maximalize s_ht
                    fun_05 = @(w_05)((fit_curve_05(1)*w_05+fit_curve_05(2)));
                    fun_95 = @(w_95)((fit_curve_95(1)*w_95+fit_curve_95(2)));
                    lb = 0;
                    ub = 1;
                    A = [];
                    b = [];
                    Aeq = [];
                    beq = [];
                    % w_05 = fminsearch(@(w_05) fun_05(w_05)*-1, weight_start_05);
                    options = optimoptions('fmincon','Display','off');
                    w_05 = fmincon(@(w_05) -1*fun_05(w_05),weight_start_05,A,b,Aeq,beq,lb,ub,[],options);
                    w_95 = fmincon(@(w_95) -1*fun_95(w_95),weight_start_95,A,b,Aeq,beq,lb,ub,[], options);
                    weights_end_05(k) = w_05;
                    weights_end_95(k) = w_95;
                end    
        end
    end
    final_weights = [weights_end_05; weights_end_95];
end