% Function calculate the quantile for particular weights
   
function result = quantile_weight(weights, price_scenario_RB, price_scenario_RDN, alpha, k, nr_U, measure)

   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   % weights - vector of weights
   % price_scenario_RB - prediction prices for the complementary market
   % price_scenario_RDN - prediction prices for the day-ahead market
   % alpha - order of risk measure
   % k - number of points in the third window
   % nr_U - number of scenarios
   % measure - measure of risk
   
   U = rand(1,nr_U);
   scenario_h_t = zeros(length(weights),length(U));
   quantile_weights = zeros(1,length(weights));
   
   switch measure
       case 'quantile'
           for i = 1 :length(weights)
                for j = 1 :length(U)  
                    scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                end
                quantile_weights(i) = quantile(scenario_h_t(i,:),alpha);
           end
       case 'expectiles'
           for i = 1 :length(weights)
                for j = 1 :length(U)  
                    scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                end
                quantile_weights(i) = expectile(scenario_h_t(i,:),alpha);
           end
       case 'ES' 
           for i = 1 :length(weights)
                for j = 1 :length(U)  
                    scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                end
                VaR = quantile(scenario_h_t(i,:),alpha);
               if alpha == 0.05
                    index = find(scenario_h_t(i,:) < VaR);
                    help_vec = zeros(1,length(index));
                    for z = 1:length(index)
                        help_vec(z) = scenario_h_t(i,index(z));
                    end
                    quantile_weights(i) = mean(help_vec);
                end
                if alpha == 0.95
                    index = find(scenario_h_t(i,:) > VaR);
                    help_vec = zeros(1,length(index));
                    for z = 1:length(index)
                        help_vec(z) = scenario_h_t(i,index(z));
                    end
                    quantile_weights(i) = mean(help_vec);
                end
           end
      case 'sharpe'
            for i = 1 :length(weights)
                for j = 1 :length(U)  
                    scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                end
                quantile_weights(i) = mean(scenario_h_t(i,:))/std(scenario_h_t(i,:));
            end
       case 'q_50_IQR'
            for i = 1 :length(weights)
                for j = 1 :length(U)  
                    scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                end
                quantile_weights(i) = quantile(scenario_h_t(i,:), 0.5)/iqr(scenario_h_t(i,:));
            end   
       case 'median'
            for i = 1 :length(weights)
                for j = 1 :length(U) 
                    scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                end
                quantile_weights(i) = quantile(scenario_h_t(i,:), 0.5);
            end 
       case 'mean'
            for i = 1 :length(weights)
                for j = 1 :length(U)  
                    scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                end
                quantile_weights(i) = mean(scenario_h_t(i,:));
            end 
       case 'std'
            for i = 1 :length(weights)
                for j = 1 :length(U)  
                    scenario_h_t(i,j) = weights(i)*price_scenario_RB(k,j)+ (1-weights(i))*price_scenario_RDN(k,j);
                end
                quantile_weights(i) = std(scenario_h_t(i,:));
            end
   end      
    result = quantile_weights;
end