function [total_profit_05, total_profit_95, VaR_95_historical_05,VaR_95_historical_95, mean_weight_05,  mean_weight_95, std_05, std_95, shape_ratio_weight_05, shape_ratio_weight_95, q50_IQR_weight_05, q50_IQR_weight_95, median_weight_05, median_weight_95, ES_05, ES_95, expectiles_05, expectiles_95, mean_05, mean_95, quantile_95_95, ES_95_95, expectiles_95_95] = strategy_evaluation_metrics_risk_company(real_price_RDN, real_price_RB, amount_day_3, weight_05_quantile,weight_95_quantile,weight_05_expectiles, weight_95_expectiles, weight_05_ES, weight_95_ES, weight_05_sharpe, weight_05_q_50_IQR, weight_05_median, weight_95_mean, weight_05_std, measure)


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % amount_day_3 - amount of day in validation's window = 390;
    % real_price_RB - real prices for the day ahead market in the third window
    % real_price_RDN - real prices for the complementary market in the third window
    % weights - fixed weights
    
        %%%%%%%%%%%%%%%%%%%%%% Chosing the strategy %%%%%%%%%%%%%%%%%%%%%%%%%%%
    switch measure 
        case 'quantile'
            weights_end_05 = weight_05_quantile;
            weights_end_95 = weight_95_quantile;
        case 'expectiles'  
            weights_end_05 = weight_05_expectiles;
            weights_end_95 = weight_95_expectiles;
        case 'ES'
            weights_end_05 = weight_05_ES;
            weights_end_95 = weight_95_ES;
        case 'sharpe'  
            weights_end_05 = weight_05_sharpe;
            weights_end_95 = weight_05_sharpe;
        case 'q_50_IQR' 
            weights_end_05 = weight_05_q_50_IQR;
            weights_end_95 = weight_05_q_50_IQR;
        case 'median' 
            weights_end_05 = weight_05_median;
            weights_end_95 = weight_05_median;
        case 'mean' 
            weights_end_05 = weight_95_mean;
            weights_end_95 = weight_95_mean;
        case 'std'  
            weights_end_05 = weight_05_std;
            weights_end_95 = weight_05_std; 
    end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Hourly profit %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    profit_05 = zeros(amount_day_3*24,1);
    profit_95 = zeros(amount_day_3*24,1);
    
    for i = 1:amount_day_3*24
        profit_05(i) = real_price_RB(i); %weights_end_05(i) * real_price_RB(i) + (1 - weights_end_05(i))* real_price_RDN(i);  
        profit_95(i) = real_price_RB(i); %weights_end_95(i) * real_price_RB(i) + (1 - weights_end_95(i))* real_price_RDN(i);  
    end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Total profit %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    total_profit_05 = sum(profit_05);
    total_profit_95 = sum(profit_95);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 5% Value atRisk (VaR) %%%%%%%%%%%%%%%%%%%%%%
    day_profit_05 = zeros(amount_day_3,1);
    day_profit_95 = zeros(amount_day_3,1);
    day_weight_05 = zeros(amount_day_3,1);
    day_weight_95 = zeros(amount_day_3,1);
    
    for k = 1:amount_day_3  
        day_profit_05(k) = sum(profit_05((k-1)*24+1:k*24)); 
        day_profit_95(k) = sum(profit_95((k-1)*24+1:k*24));
        day_weight_05(k) = mean(weights_end_05((k-1)*24+1:k*24)); % average weight in given day
        day_weight_95(k) = mean(weights_end_95((k-1)*24+1:k*24));
    end

    VaR_95_historical_05 = quantile(day_profit_05,0.05);
    VaR_95_historical_95 = quantile(day_profit_95,0.05);
    mean_weight_05 = mean(day_weight_05);
    mean_weight_95 = mean(day_weight_95);  
    
    % Qauntile 95%
    quantile_95_95 = quantile(day_profit_95,0.95);
    
    % Volatility
    std_05 = std(day_profit_05);
    std_95 = std(day_profit_95);
    
        % Shape ratio
    shape_ratio_weight_05 = mean(day_profit_05)/std(day_profit_05);
    shape_ratio_weight_95 = mean(day_profit_95)/std(day_profit_95);

    q50_IQR_weight_05 = quantile(day_profit_05,0.5)/ iqr(day_profit_05);
    q50_IQR_weight_95 = quantile(day_profit_95,0.5)/ iqr(day_profit_95);
    
    % Median
    median_weight_05 = quantile(day_profit_05,0.5);
    median_weight_95 = median(day_profit_95);

    % Expected shortfall
    index_weights_05 = find(day_profit_05 < VaR_95_historical_05);
    index_weights_95 = find(day_profit_95 < VaR_95_historical_95);
    help_vec_05 = zeros(1,length(index_weights_05));
    help_vec_95 = zeros(1,length(index_weights_95));
    for z = 1:length(index_weights_05)
        help_vec_05(z) = day_profit_05(index_weights_05(z));
    end
    for z = 1:length(index_weights_95)
        help_vec_95(z) = day_profit_95(index_weights_95(z));
    end
    ES_05 = mean(help_vec_05); % below VaR
    ES_95 = mean(help_vec_95); % below VaR  
    
    % Expected shortfall 95%
    index_95 = find(day_profit_95 > quantile_95_95);
    help_vec_95_95 = zeros(1,length(index_95));
    for z = 1:length(index_95)
        help_vec_95_95(z) = day_profit_95(index_95(z));
    end
    ES_95_95 = mean(help_vec_95_95); % above VaR
    
    % Expectiles 5%
    expectiles_05 = expectile(day_profit_05, 0.05);
    expectiles_95 = expectile(day_profit_95, 0.05);
    
    % Expectiles 95%
    expectiles_95_95 = expectile(day_profit_95, 0.95);
    
    % Mean
    mean_05 = mean(day_profit_05);
    mean_95 = mean(day_profit_95);
       
end
