function daily_profit_import_data(day_profit_05_quantile,day_profit_95_quantile,day_profit_05_expectiles, day_profit_95_expectiles, day_profit_05_ES, day_profit_95_ES, day_profit_05_sharpe, day_profit_05_q_50_IQR, day_profit_05_median, day_profit_95_mean, day_profit_05_std, fname, model)
   
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
    % As an input data are given the files 'txt' contain the daily profit 
    % for different risk measures.    

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%% Comparison of daily profits %%%%%%%%%%%%%%%%%%%%
    line4_h = 235;
    line5_h = line4_h + 275; %367;

    %%%%%%%%%%%%%%%%%%%%%%% Plots for risk minimization %%%%%%%%%%%%%%%%%%%%
    figure
    hold on
    plot(day_profit_05_quantile,'Color',[0.9290, 0.6940, 0.1250])
    plot(day_profit_05_expectiles, '--','Color',[0.4660, 0.6740, 0.1880])
    plot(day_profit_05_ES,'m')
    plot(day_profit_05_std,'Color',[0, 0.4470, 0.7410],'MarkerSize', 4)
    xlim([1, length(day_profit_05_quantile)])
    ylim([-1000,900])
   % xlabel('Date [08.01.2019 - 31.12.2020]', 'fontsize',13)
    ylabel('Price [PLN/MWh]', 'fontsize',15)
    legend('quantile', 'expectiles', 'ES', 'std')
    title('Comparison of daily profits for different risk measures of risk minimization strategy')
    set(gca,'Xtick',[1, line4_h, line5_h, length(day_profit_05_quantile)])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    set(gca, 'YTick', [-800,-400,0,400,800])
    set(gca,'fontsize',14)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    switch model
        case 'QRA'
            saveas(gca, fullfile(fname, 'risk_min_profit_Poland'), 'fig');
        case 'single'  
            saveas(gca, fullfile(fname, 'risk_min_profit_Poland_single'), 'fig');
    end

    %%%%%%%%%%%%%%%%%%%%%% Plots for optimal strategy %%%%%%%%%%%%%%%%%%%%
    figure
    hold on
    plot(day_profit_05_sharpe, 'm')
    plot(day_profit_05_q_50_IQR, 'Color',[0.4660, 0.6740, 0.1880])
    xlim([1, length(day_profit_05_sharpe)])
    ylim([-420,620])
    % xlabel('Date [08.01.2019 - 31.12.2020]', 'fontsize',13)
    ylabel('Price [PLN/MWh]', 'fontsize',15)
    legend('sharpe ratio', 'q_{50}/IQR')
    title('Comparison of daily profits for different risk measures of optimal strategy')
    set(gca,'Xtick',[1, line4_h, line5_h, length(day_profit_05_sharpe)])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    set(gca, 'YTick', [-300,0,300,600])
    set(gca,'fontsize',14)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    switch model
        case 'QRA'
            saveas(gca, fullfile(fname, 'optimal_strategy_profit_Poland'), 'fig');
        case 'single'  
            saveas(gca, fullfile(fname, 'optimal_strategy_profit_Poland_single'), 'fig');
    end

    %%%%%%%%%%%%%%%%%%%%%% Plots for profit maximization %%%%%%%%%%%%%%%%%%%%
    figure
    hold on
    plot(day_profit_95_quantile,'Color',[0, 0.4470, 0.7410])
    plot(day_profit_95_expectiles,'m')
    plot(day_profit_95_mean,'Color',[0.9290, 0.6940, 0.1250])
    plot(day_profit_95_ES,'--','Color',[0.4660, 0.6740, 0.1880])
    plot(day_profit_05_median,':','Color', [0.8500, 0.3250, 0.0980])
    xlim([1, length(day_profit_95_quantile)])
    ylim([-2800,4500])
    xlabel('Date [08.01.2019 - 31.12.2020]', 'fontsize',13)
    ylabel('Price [PLN/MWh]', 'fontsize',15)
    legend('quantile', 'expectiles','mean','ES', 'median')
    title('Comparison of daily profits for different risk measures of profit maximization strategy')
    set(gca,'Xtick',[1, line4_h, line5_h, length(day_profit_95_quantile)])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    set(gca, 'YTick', [-2000,0,2000,4000])
    set(gca,'fontsize',14)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    switch model
        case 'QRA'
            saveas(gca, fullfile(fname, 'profit_max_profit_Poland'), 'fig');
        case 'single'  
            saveas(gca, fullfile(fname, 'profit_max_profit_Poland_single'), 'fig');
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%% Comparison the distribution of daily profits: histogram %%%%%%%
    
    %%%%%%%%%%%%%%%%%%%%%%% Plots for risk minimization %%%%%%%%%%%%%%%%%%%%
    
    binRange = -800:170:1000;
    h_05_quantile = histcounts(day_profit_05_quantile,binRange, 'Normalization', 'probability');
    h_05_expectiles = histcounts(day_profit_05_expectiles,binRange, 'Normalization', 'probability');
    h_05_ES = histcounts(day_profit_05_ES, binRange,'Normalization', 'probability');
    h_05_std = histcounts(day_profit_05_std,binRange, 'Normalization', 'probability');

    figure
    h = subplot(1,3,1);
    set(h,'position',[0.0477083333333333 0.148504273504274 0.286666666666667 0.78076923076923]);    
    bb = bar(binRange(1:end-1), [h_05_quantile; h_05_expectiles; h_05_ES; h_05_std]');
    bb(1).FaceColor = [0.9290, 0.6940, 0.1250]; 
    bb(2).FaceColor = [0.4660, 0.6740, 0.1880];
    bb(3).FaceColor = 'm';
    bb(4).FaceColor = [0, 0.4470, 0.7410];
    legend('quantile', 'expectiles', 'ES', 'std')
%     title('The distribution of daily profits for risk minimization and different risk measures')
    title('Risk minimization strategy')
    ylabel('p')
    set(gca,'fontsize',20)
    set(gca,'XTick',[-800 -400 0 400 800]);
    box on
    hold off
    
     %%%%%%%%%%%%%%%%%%%%%% Plots for optimal strategy %%%%%%%%%%%%%%%%%%%%
     
    binRange = -800:100:900;
    h_05_sharpe = histcounts(day_profit_05_sharpe,binRange, 'Normalization', 'probability');
    h_05_q_50_IQR = histcounts(day_profit_05_q_50_IQR,binRange, 'Normalization', 'probability');
   
    h1 = subplot(1,3,2);
    set(h1,'position',[0.396875 0.150641025641026 0.270833333333333 0.774358974358974]);
    b = bar(binRange(1:end-1), [h_05_sharpe; h_05_q_50_IQR]');
    b(1).FaceColor = 'm';
    b(2).FaceColor = [0.4660, 0.6740, 0.1880];
    legend('sharpe ratio', 'q_{50}/IQR')
%     title('The distribution of daily profits for optimal strategy and different risk measures')
    title('Optimal strategy')
%     ylabel('p')
    set(gca,'fontsize',20)
    set(gca,'XTick',[-800 -400 0 400 800]);
    box on
    hold off

    
    %%%%%%%%%%%%%%%%%%%%%% Plots for profit maximization %%%%%%%%%%%%%%%%%%%%
    
    binRange = -800:170:1000;
    h_95_quantile = histcounts(day_profit_95_quantile,binRange, 'Normalization', 'probability');
    h_95_expectiles = histcounts(day_profit_95_expectiles,binRange, 'Normalization', 'probability');
    h_95_mean = histcounts(day_profit_95_mean, binRange,'Normalization', 'probability');
    h_95_ES = histcounts(day_profit_95_ES,binRange, 'Normalization', 'probability');
    h_95_median = histcounts(day_profit_05_median,binRange,'Normalization', 'probability');

    h2 = subplot(1,3,3);
    set(h2,'position',[0.720833333333333 0.150641025641026 0.265625 0.781837606837606]);
    bbb = bar(binRange(1:end-1), [h_95_quantile; h_95_expectiles; h_95_mean; h_95_ES; h_95_median]');
    bbb(1).FaceColor = [0, 0.4470, 0.7410];
    bbb(2).FaceColor = 'm';
    bbb(3).FaceColor = [0.9290, 0.6940, 0.1250];
    bbb(4).FaceColor = [0.4660, 0.6740, 0.1880];
    bbb(5).FaceColor = [0.8500, 0.3250, 0.0980];
    legend('quantile', 'expectiles', 'mean','ES', 'median')
%     title('The distribution of daily profits for profit maximization and different risk measures')
    title('Profit maximization strategy')
%     ylabel('p')
    set(gca,'fontsize', 20)
    box on
    set(gca,'XTick',[-800 -400 0 400 800]);
    hold off
    switch model
        case 'QRA'
            saveas(gca, fullfile(fname, 'sub_dist_profit_Poland'), 'fig');
        case 'single'  
            saveas(gca, fullfile(fname, 'sub_dist_profit_Poland_single'), 'fig');
    end
 
end