function  plots_data(data,endd_1, endd_2, real_price_RDN, real_price_RB, prediction_QRA_RB, prediction_QRA_RDN,amount_day_3, nr_U, option, fname);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % data - input data
    % endd_1 - choose the last hour to calibrate the individual model
    % endd_2 - choose the last hour in second window
    % real_price_RDN - real prices for the day ahead market in the third window
    % real_price_RB - real prices for the complementary market in the third window
    % prediction_QRA_RB - prediction prices using quantile regression method for the day ahead market
    % prediction_QRA_RDN - prediction prices using quantile regression method for the complementary market
    % amount_day_3 - amount of day in validation's window 
    % nr_U - number of scenarios
    % option - method of finding value of w_ht, which maximalize s_ht 

    line1_h = endd_1/24;
    line2_h = (endd_1 + endd_2)/24;
    line3_h = line2_h + 360;
    line4_h = 235;
    line5_h = line4_h + 275; %367;

    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % %%%%% Plots for RDN and RB market and chosen hours %%%%%%%%%%%
    % green - [0.4660, 0.6740, 0.1880] 
    % blue - [0, 0.4470, 0.7410]
    % pink - 'm', [0.749019622802734 0 0.749019622802734]
    % yellow - [0.9290, 0.6940, 0.1250]

    % Day-ahead market
    figure 
    % subplot(2,1,1)
    hold on
    plot(data(2:24:end,3),'Color',[0, 0.4470, 0.7410], 'MarkerSize', 0.5) 
    plot(data(8:24:end,3),'m', 'MarkerSize', 0.5) 
    plot(data(12:24:end,3),':','Color', [0.9290, 0.6940, 0.1250], 'MarkerSize', 1.2)
    plot(data(16:24:end,3),'--', 'Color', [0.4660, 0.6740, 0.1880], 'MarkerSize', 0.8)
    xlim([1, length(data(8:24:end,3))])
    ylim([0, 1020])
    % xlabel('Date', 'fontsize',13)
    ylabel('Price [PLN/MWh]', 'fontsize',13)
    title('Day-ahead market prices')
    text(line2_h,10,'Calibration window','HorizontalAlignment','right','VerticalAlignment','top','fontsize',20)
    text(line2_h+200,10,'Validation window','HorizontalAlignment','left','VerticalAlignment','top','fontsize',20)
    hold on 
    plot(line2_h*[1,1],ylim, 'r--','MarkerSize',6)
    set(gca,'Xtick',[1, line1_h,line2_h, line3_h, length(data(8:24:end,3))])
    set(gca,'Xticklabel',{'01.01.2017','06.01.2018', '07.01.2019',' 01.01.2020' , '31.12.2020'})
    set(gca, 'YTick', [0,200,600,1000])
    set(gca,'fontsize',14)
    legend( '2 h','8 h', '12 h', '16 h')
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    saveas(gca, fullfile(fname, 'data_Poland_RDN'), 'fig');
    
    % Balancing market
    figure
    % subplot(2,1,2)
    hold on
    plot(data(2:24:end,4),'Color',[0, 0.4470, 0.7410], 'MarkerSize', 0.5) 
    plot(data(8:24:end,4),'m', 'Markersize', 0.5) 
    plot(data(12:24:end,4),':','Color', [0.9290, 0.6940, 0.1250], 'MarkerSize', 1.2)
    plot(data(16:24:end,4),'--','Color', [0.4660, 0.6740, 0.1880], 'MarkerSize', 0.8)
    xlim([1, length(data(8:24:end,4))])
    % xlabel('Date', 'fontsize',13)
    ylabel('Price [PLN/MWh]', 'fontsize',15)
    title('Balancing market prices')
    plot(line2_h*[1,1],ylim, 'r--','MarkerSize',6)
    set(gca,'Xtick',[1, line1_h,line2_h, line3_h, length(data(8:24:end,3))])
    set(gca,'Xticklabel',{'01.01.2017','06.01.2018', '07.01.2019', ' 01.01.2020','31.12.2020'})
    set(gca,'fontsize',14)
    legend( '2 h','8 h', '12 h', '16 h')
    box on
    hold off
set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    saveas(gca, fullfile(fname, 'data_Poland_RB'), 'fig');
    
    % Spread between balancing and day-ahead market
    
    figure
    %subplot(2,1,2)
    hold on
    plot(data(2:24:end,4)-data(2:24:end,3),'Color',[0, 0.4470, 0.7410], 'MarkerSize', 0.5) 
    plot(data(8:24:end,4)-data(8:24:end,3),'m', 'Markersize', 0.5) 
    plot(data(12:24:end,4)- data(12:24:end,3),':','Color', [0.9290, 0.6940, 0.1250], 'MarkerSize', 1.2)
    plot(data(16:24:end,4)- data(16:24:end,3),'--','Color', [0.4660, 0.6740, 0.1880], 'MarkerSize', 0.8)
    xlim([1, length(data(8:24:end,4))])
    ylim([-500,1500])
    xlabel('Date', 'fontsize',13)
    ylabel('Price [PLN/MWh]', 'fontsize',15)
    title('Spread')
    plot(line2_h*[1,1],ylim, 'r--','MarkerSize',6)
    set(gca,'Xtick',[1, line1_h,line2_h, line3_h, length(data(8:24:end,3))])
    set(gca,'Xticklabel',{'01.01.2017','06.01.2018', '07.01.2019', ' 01.01.2020','31.12.2020'})
    set(gca,'fontsize',14)
    legend( '2 h','8 h', '12 h', '16 h')
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    saveas(gca, fullfile(fname, 'spread_Poland_RDN_RB'), 'fig');

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%% Plot of forecasting points %%%%%%%%%%%%%%%%%

    % Day-ahead market
    
    % hour 2
    figure
    hold on
    plot(real_price_RDN(2:24:end), 'Marker','+', 'MarkerSize',3,'LineStyle','none', 'Color', [0, 0.4470, 0.7410]) 
    plot(prediction_QRA_RDN(2:24:end,5),'Color',[0.9290, 0.6940, 0.1250], 'MarkerSize',0.85);
    plot(prediction_QRA_RDN(2:24:end,95),'Color', [0.9290, 0.6940, 0.1250],'MarkerSize',0.85);
    xlim([1, length(real_price_RDN(2:24:end))])
    ylim([0,400])
    %xlabel('Date', 'fontsize',13)
    ylabel('Price [PLN/MWh]', 'fontsize',15)
    legend('real price','90% PI')
    title({'2 h'},'FontWeight', 'Normal')
    %h = suptitle('Day-ahead market prices');
    %set(h, 'FontWeight','bold');
    set(gca,'Xtick',[1, line4_h, line5_h, length(real_price_RDN(2:24:end))])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    set(gca, 'YTick', [50,200,400])
    set(gca,'fontsize',16)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    saveas(gca, fullfile(fname, 'forecast_Poland_RDN_2'), 'fig');
    
    % hour 12
    figure
    hold on 
    plot(real_price_RDN(12:24:end),'m','Marker','*','MarkerSize',2,'LineStyle','none') 
    plot(prediction_QRA_RDN(12:24:end,5),'Color',[0.4660, 0.6740, 0.1880], 'MarkerSize',0.85);
    plot(prediction_QRA_RDN(12:24:end,95),'Color',[0.4660, 0.6740, 0.1880], 'MarkerSize',0.85);
    xlim([1, length(real_price_RDN(12:24:end))])
    ylim([0,1310])
    xlabel('Date', 'fontsize',13)
    ylabel('Price [PLN/MWh]', 'fontsize',15)
    legend('real price','90% PI')
    title({'12 h'},'FontWeight', 'Normal')
    set(gca,'Xtick',[1, line4_h, line5_h, length(real_price_RDN(2:24:end))])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    set(gca, 'YTick', [0,400,800,1300])
    set(gca,'fontsize',16)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    saveas(gca, fullfile(fname, 'forecast_Poland_RDN_12'), 'fig');
    
    
    % % Balancing market
    
    % hour 2
    figure
    hold on
    plot(real_price_RB(2:24:end),'Marker','+', 'MarkerSize',3,'LineStyle','none', 'Color', [0, 0.4470, 0.7410]) 
    plot(prediction_QRA_RB(2:24:end,5),'Color',[0.9290, 0.6940, 0.1250],'MarkerSize',0.85);
    plot(prediction_QRA_RB(2:24:end,95),'Color',[0.9290, 0.6940, 0.1250],'MarkerSize',0.85);
    xlim([1, length(real_price_RB(2:24:end))])
    ylim([0,400])
    ylabel('Price [PLN/MWh]', 'fontsize',15)
    legend('real price','90% PI')
    title({'2 h'},'FontWeight', 'Normal')
    % h = suptitle('Balancing market prices');
    % set(h, 'FontWeight','bold');
    set(gca,'Xtick',[1, line4_h, line5_h, length(real_price_RB(2:24:end))])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    set(gca, 'YTick', [50,200,400])
    set(gca,'fontsize',16)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    saveas(gca, fullfile(fname, 'forecast_Poland_RB_2'), 'fig');
    
    % hour 12
    figure
    hold on
    plot(real_price_RB(12:24:end),'m','Marker','*','MarkerSize',2,'LineStyle','none') 
    plot(prediction_QRA_RB(12:24:end,5),'Color',[0.4660, 0.6740, 0.1880], 'MarkerSize',0.85);
    plot(prediction_QRA_RB(12:24:end,95),'Color',[0.4660, 0.6740, 0.1880], 'MarkerSize',0.85);
    xlim([1, length(real_price_RB(12:24:end))])
    ylim([0,1310])
    xlabel('Date', 'fontsize',13)
    ylabel('Price [PLN/MWh]', 'fontsize',15)
    legend('real price','90% PI')
    title({'12 h'},'FontWeight', 'Normal')
    set(gca,'Xtick',[1, line4_h, line5_h, length(real_price_RB(12:24:end))])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    set(gca, 'YTick', [0,400,800,1300])
    set(gca,'fontsize',16)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    saveas(gca, fullfile(fname, 'forecast_Poland_RB_12'), 'fig');


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%% Plots of weights %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Plot of average hourly weights
    
    weights = 0:0.1:1;
    time = 1:24;
    time_daily = 1:amount_day_3;
    
    profit_h = zeros(length(weights),amount_day_3*24);
    for i = 1:length(weights)
        for k = 1:amount_day_3*24
            profit_h(i,k) = weights(i).* real_price_RB(k) + (1 - weights(i)).* real_price_RDN(k) - real_price_RDN(k);
        end
    end
    
    profit_avg_hour = zeros(length(weights),24);
    risk_avg_hour = zeros(length(weights),24);
    for i = 1:length(weights)
        for j = 1:24
            profit_avg_hour(i,j) = mean(profit_h(i,j:24:end));
            risk_avg_hour(i,j) = quantile(profit_h(i,j:24:end), 0.05);
        end
    end
    
    % Plots of weights 3-D
    
    % Profit
    figure
    [t,w] = meshgrid(time,weights);
    surf(t,w,profit_avg_hour)
    xlabel('Hour')
    ylabel('Weight')
    zlabel('Hourly profit')
    title('Average hourly profit')
    saveas(gca, fullfile(fname, '3D_hourly_profit'), 'fig');
    
    % Risk
    figure
    [tt,ww] = meshgrid(time,weights);
    surf(tt,ww,abs(risk_avg_hour))
    xlabel('Hour')
    ylabel('Weight')
    zlabel('Absolute value of hourly risk')
    title('Average hourly 5% quantile')
    saveas(gca, fullfile(fname, '3D_hourly_risk'), 'fig');
    
    % Risk
    figure
    [tt,ww] = meshgrid(time,weights);
    surf(tt,ww,risk_avg_hour)
    xlabel('Hour')
    ylabel('Weight')
    zlabel('Value of hourly risk')
    title('Average hourly 5% quantile')
    
    risk_avg_hour = risk_avg_hour;
    
    % Daily profit
    
    profit_all = zeros(length(weights), amount_day_3);
    for i = 1:length(weights)
        for k = 1:amount_day_3
            profit_hour =  weights(i).* real_price_RB((k-1)*24+1:k*24) + (1 - weights(i)).* real_price_RDN((k-1)*24+1:k*24) - real_price_RDN((k-1)*24+1:k*24);
            profit_all(i,k) = sum(profit_hour);  % daily profit; sum czy mean?
        end
%         hold on
%         %plot(profit_all(i, :), 'DisplayName',num2str(weights(i)))
%         hold off
    end
    
    % Plots of weights 3-D
    figure
    [tt,ww] = meshgrid(time_daily,weights);
    surf(tt,ww,profit_all)
    title('Daily profit')
    xlabel('Day')
    ylabel('Weight')
    zlabel('Daily profit')
    saveas(gca, fullfile(fname, '3D_daily_profit'), 'fig');
    
    
    %%% Profit only for weight equal to 1
    profit_w_1 = zeros(amount_day_3,1);
    weight = 1;
    for k = 1:amount_day_3
        profit_hour_w_1  = weight.* real_price_RB((k-1)*24+1:k*24) + (1 - weight).* real_price_RDN((k-1)*24+1:k*24) - real_price_RDN((k-1)*24+1:k*24);
        profit_w_1(k) = sum(profit_hour_w_1);
    end
    
    figure
    plot(time_daily, profit_w_1, 'Color', [0, 0.4470, 0.7410])
    title('Daily profit with weight equal to 1')
    xlabel('Day')
    ylabel('Daily profit')
    xlim([1, length(profit_w_1)])
    ylim([-3000,4300])
    set(gca,'Xtick',[1, line4_h, line5_h, length(profit_w_1)])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    set(gca, 'YTick', [-2000,0,2000,4000])
    set(gca,'fontsize',14)
    box on
    hold off
    saveas(gca, fullfile(fname, '2D_avg_daily_profit'), 'fig');
    
end