function [total_profit_05, total_profit_95, VaR_95_historical_05,VaR_95_historical_95, mean_weight_05,  mean_weight_95]= strategy_evaluation_metrics(real_price_RDN, real_price_RB, amount_day_3, nr_U, option, prediction_QRA_RB, prediction_QRA_RDN, measure)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % real_price_RDN - real prices for the day ahead market in the third window
    % real_price_RB - real prices for the complementary market in the third window
    % prediction_QRA_RB - prediction prices using quantile regression method for the day ahead market
    % prediction_QRA_RDN - prediction prices using quantile regression method for the complementary market
    % amount_day_3 - amount of day in validation's window 
    % nr_U - number of scenarios
    % option - method of finding value of w_ht, which maximalize s_ht 
    % measure - measure of risk

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%% Strategy evaluation metrics %%%%%%%%%%%%%%%%%%%%%%%%
    weights_end = optimal_scenarios_measure(prediction_QRA_RB, prediction_QRA_RDN,amount_day_3, nr_U, option, measure);
    weights_end_05  = weights_end(1,:);
    weights_end_95  = weights_end(2,:);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Hourly profit %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    profit_05 = zeros(amount_day_3*24,1);
    profit_95 = zeros(amount_day_3*24,1);

    for i = 1:amount_day_3*24
        profit_05(i) = weights_end_05(i) * real_price_RB(i) + (1 - weights_end_05(i))* real_price_RDN(i) - real_price_RDN(i);
        profit_95(i) = weights_end_95(i) * real_price_RB(i) + (1 - weights_end_95(i))* real_price_RDN(i) - real_price_RDN(i);
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Total profit %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    total_profit_05 = sum(profit_05);
    total_profit_95 = sum(profit_95);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 5% Value atRisk (VaR) %%%%%%%%%%%%%%%%%%%%%%
    day_profit_05 = zeros(amount_day_3,1);
    day_profit_95 = zeros(amount_day_3,1);
    day_weight_05 = zeros(amount_day_3,1);
    day_weight_95 = zeros(amount_day_3,1);
    
    for k = 1:amount_day_3  
        day_profit_05(k) = sum(profit_05((k-1)*24+1:k*24)); 
        day_profit_95(k) = sum(profit_95((k-1)*24+1:k*24));
        day_weight_05(k) = mean(weights_end_05((k-1)*24+1:k*24)); % average weight in given day
        day_weight_95(k) = mean(weights_end_95((k-1)*24+1:k*24));
    end

    VaR_95_historical_05 = quantile(day_profit_05,0.05);
    VaR_95_historical_95 = quantile(day_profit_95,0.05);
    mean_weight_05 = mean(day_weight_05);
    mean_weight_95 = mean(day_weight_95);   

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Saving data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
%     weights_end_05 = weights_end_05';
%     weights_end_95 = weights_end_95';
%     
%     save day_profit_05_quantile.txt day_profit_05 -ascii
%     save day_profit_95_quantile.txt day_profit_95 -ascii
%     save day_weight_05_quantile.txt day_weight_05 -ascii
%     save day_weight_95_quantile.txt day_weight_95 -ascii
%     save weight_05_quantile.txt weights_end_05 -ascii
%     save weight_95_quantile.txt weights_end_95 -ascii
    
end



