function [total_profit_05, total_profit_95, VaR_95_historical_05,VaR_95_historical_95, mean_weight_05,  mean_weight_95]= strategy_evaluation_metrics_scale_forecast(real_price_RDN, real_price_RB, amount_day_3, nr_U, option, price_scenario_RB_saved, price_scenario_RDN_saved, measure, scale_p)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % real_price_RDN - real prices for the day ahead market in the third window
    % real_price_RB - real prices for the complementary market in the third window
    % prediction_QRA_RB - prediction prices using quantile regression method for the day ahead market
    % prediction_QRA_RDN - prediction prices using quantile regression method for the complementary market
    % amount_day_3 - amount of day in validation's window 
    % nr_U - number of scenarios
    % option - method of finding value of w_ht, which maximalize s_ht 
    % measure - measure of risk

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%% Strategy evaluation metrics %%%%%%%%%%%%%%%%%%%%%%%%
    
    [final_weights_05, final_weights_95] = optimal_scenarios_measure_scale_forecast(price_scenario_RB_saved, price_scenario_RDN_saved, amount_day_3, nr_U, option, measure, scale_p);

    total_profit_05 = zeros(1,size(final_weights_05,1));
    total_profit_95 = zeros(1,size(final_weights_05,1));
    VaR_95_historical_05 = zeros(1,size(final_weights_05,1));
    VaR_95_historical_95 = zeros(1,size(final_weights_05,1));
    mean_weight_05 = zeros(1,size(final_weights_05,1));
    mean_weight_95 = zeros(1,size(final_weights_05,1));
    
    for w = 1:size(final_weights_05,1)
        
        weights_end_05  = final_weights_05(w,:);
        weights_end_95  = final_weights_95(w,:);
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Hourly profit %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        profit_05 = zeros(amount_day_3*24,1);
        profit_95 = zeros(amount_day_3*24,1);

        for i = 1:amount_day_3*24
            real_price_RB_05 = real_price_RB(i) - (real_price_RB(i)*scale_p(w) * weights_end_05(i));
            real_price_RDN_05 = real_price_RDN(i) + (real_price_RDN(i)*scale_p(w)* weights_end_05(i));
            real_price_RB_95 = real_price_RB(i) - (real_price_RB(i)*scale_p(w)* weights_end_95(i));
            real_price_RDN_95 = real_price_RDN(i) + (real_price_RDN(i)*scale_p(w) * weights_end_95(i));
            profit_05(i) = weights_end_05(i) * real_price_RB_05 + (1 - weights_end_05(i))* real_price_RDN_05 - real_price_RDN(i);
            profit_95(i) = weights_end_95(i) * real_price_RB_95 + (1 - weights_end_95(i))* real_price_RDN_95 - real_price_RDN(i);
        end

        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Total profit %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        total_profit_05(w) = sum(profit_05);
        total_profit_95(w) = sum(profit_95);

        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 5% Value atRisk (VaR) %%%%%%%%%%%%%%%%%%%%%%
        day_profit_05 = zeros(amount_day_3,1);
        day_profit_95 = zeros(amount_day_3,1);
        day_weight_05 = zeros(amount_day_3,1);
        day_weight_95 = zeros(amount_day_3,1);

        for k = 1:amount_day_3  
            day_profit_05(k) = sum(profit_05((k-1)*24+1:k*24)); 
            day_profit_95(k) = sum(profit_95((k-1)*24+1:k*24));
            day_weight_05(k) = mean(weights_end_05((k-1)*24+1:k*24)); % average weight in given day
            day_weight_95(k) = mean(weights_end_95((k-1)*24+1:k*24));
        end

        VaR_95_historical_05(w) = quantile(day_profit_05,0.05);
        VaR_95_historical_95(w) = quantile(day_profit_95,0.05);
        mean_weight_05(w) = mean(day_weight_05);
        mean_weight_95(w) = mean(day_weight_95);   
    end
end



