function [total_profit_05, total_profit_95, VaR_95_historical_05,VaR_95_historical_95, mean_weight_05, mean_weight_95] = strategy_evaluation_metrics_single_model(data, start, endd, amount_day_3,nr_U, m,option, real_price_RDN, real_price_RB, measure)
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % data - input data
    % start - choose the first hour in calibration's window 
    % endd -  choose the last hour in calibration's window 
    % amount_day_3 - amount of day in validation's window 
    % nr_U - number of scenarios 
    % m - chosen of model in ARX model
    % option - method of finding value of w_ht, which maximalize s_ht
    % real_price_RDN - real price for the day-ahead market in the third window
    % real_price_RB - real price for the complementary market in the third window
    % measure - measure of risk
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%% Strategy evaluation metrics %%%%%%%%%%%%%%%%%%%%%%%%
    weights_end = optimal_scenarios_single_model(data, start, endd, amount_day_3,nr_U, m,option, measure);

    weights_end_05  = weights_end(1,:);
    weights_end_95  = weights_end(2,:);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Hourly profit %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    profit_05 = zeros(amount_day_3*24,1);
    profit_95 = zeros(amount_day_3*24,1);

    for i = 1:amount_day_3*24
        profit_05(i) = weights_end_05(i) * real_price_RB(i) + (1 - weights_end_05(i))* real_price_RDN(i) - real_price_RDN(i);
        profit_95(i) = weights_end_95(i) * real_price_RB(i) + (1 - weights_end_95(i))* real_price_RDN(i) - real_price_RDN(i);
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Total profit %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    total_profit_05 = sum(profit_05);
    total_profit_95 = sum(profit_95);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 5% Value atRisk (VaR) %%%%%%%%%%%%%%%%%%%%%%
    day_profit_05 = zeros(amount_day_3,1);
    day_profit_95 = zeros(amount_day_3,1);
    day_weight_05 = zeros(amount_day_3,1);
    day_weight_95 = zeros(amount_day_3,1);

    for k = 1:amount_day_3
        day_profit_05(k) = sum(profit_05((k-1)*24+1:k*24));
        day_profit_95(k) = sum(profit_95((k-1)*24+1:k*24));
        day_weight_05(k) = mean(weights_end_05((k-1)*24+1:k*24)); %average weight in given day
        day_weight_95(k) = mean(weights_end_95((k-1)*24+1:k*24));
    end

    VaR_95_historical_05 = quantile(day_profit_05,0.05);
    VaR_95_historical_95 = quantile(day_profit_95,0.05);
    mean_weight_05 = mean(day_weight_05);
    mean_weight_95 = mean(day_weight_95);   
   
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Saving data %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    weights_end_05 = weights_end_05';
    weights_end_95 = weights_end_95';
    
%     if m == '1'
%         save day_profit_std_1.txt day_profit_05 -ascii
%         save day_profit_95_std_1.txt day_profit_95 -ascii
%         save day_weight_05_std_1.txt day_weight_05 -ascii
%         save day_weight_95_std_1.txt day_weight_95 -ascii
%         save weight_05_std_1.txt weights_end_05 -ascii
%         save weight_95_std_1.txt weights_end_95 -ascii
%     end
    
end
