function weights_plots_import_data(day_weight_05_quantile,day_weight_95_quantile,day_weight_05_expectiles, day_weight_95_expectiles, day_weight_05_ES, day_weight_95_ES, day_weight_05_sharpe, day_weight_05_q_50_IQR, day_weight_05_median, day_weight_95_mean, day_weight_05_std, fname, model)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Input data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
    % As an input data are given the files 'txt' contain the daily weights 
    % for different risk measures. 

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%% Plots of weights %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    line4_h = 235;
    line5_h = line4_h + 275;

    %%%%%%%%%%%%%%%%%%%%%%%%% Comparison of daily weights %%%%%%%%%%%%%%%%%%%%%  

    %%%%%%%%%%%%%%%%%%%%%%% Plots for risk minimization %%%%%%%%%%%%%%%%%%%%%%%

    figure
    h = subplot(1,3,1);
    set(h,'position',[0.0570833333333332 0.210470085470085 0.268958333333333 0.709188034188033]);
    hold on
    plot(day_weight_05_quantile,'Color',[0.9290, 0.6940, 0.1250])
    plot(day_weight_05_expectiles, '--','Color',[0.4660, 0.6740, 0.1880])
    plot(day_weight_05_ES, 'm')
    plot(day_weight_05_std, 'Color',[0, 0.4470, 0.7410])
    xlim([1, length(day_weight_05_quantile)])
    xlabel('Date', 'fontsize',13)
    ylabel('Share on balancing market', 'fontsize',15)
    legend('quantile', 'expectiles', 'ES', 'std')
%     title('Comparison of daily weights for different risk measures of risk minimization strategy')
    title('Risk minimization strategy')
    set(gca,'Xtick',[1, line4_h, line5_h, length(day_weight_05_quantile)])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    xtickangle(45)
    set(gca,'fontsize',20)
    box on
    hold off
    
     %%%%%%%%%%%%%%%%%%%%%%% Plots for optimal strategy %%%%%%%%%%%%%%%%%%%%

    h1 = subplot(1,3,2);
    set(h1,'position',[0.389442934782609 0.215811965811966 0.274619565217391 0.71025641025641]);
    hold on
    plot(day_weight_05_sharpe, 'm')
    plot(day_weight_05_q_50_IQR,'Color', [0.4660, 0.6740, 0.1880])
    xlim([1, length(day_weight_05_sharpe)])
    xlabel('Date', 'fontsize',13)
%     ylabel('Share on balancing market', 'fontsize',15)
    legend('sharpe ratio', 'q_{50}/IQR') %, 'median')
%     title('Comparison of daily weights for different risk measures of optimal strategy')
    title('Optimal strategy')
    set(gca,'Xtick',[1, line4_h, line5_h, length(day_weight_05_sharpe)])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    xtickangle(45)
    set(gca,'fontsize',20)
    box on
    hold off 
    
    %%%%%%%%%%%%%%%%%%%%%%% Plots for profit maximization %%%%%%%%%%%%%%%%%%%%
    
    h2 = subplot(1,3,3);
    set(h2,'position',[0.730208333333333 0.211538461538462 0.257445395346656 0.717735042735043]);
    hold on
    plot(day_weight_95_quantile,'Color',[0, 0.4470, 0.7410])
    plot(day_weight_95_expectiles,'m')
    plot(day_weight_95_mean,'Color',[0.9290, 0.6940, 0.1250])
    plot(day_weight_95_ES, 'Color',[0.4660, 0.6740, 0.1880])
    plot(day_weight_05_median,':','Color', [0.8500, 0.3250, 0.0980])
    xlim([1, length(day_weight_95_quantile)])
    xlabel('Date', 'fontsize',13)
%     ylabel('Share on balancing market', 'fontsize',15)
    legend('quantile', 'expectiles','mean','ES', 'median')
%     title('Comparison of daily weights for different risk measures of profit maximization strategy')
    title('Profit maximization strategy')
    set(gca,'Xtick',[1, line4_h, line5_h, length(day_weight_95_quantile)])
    set(gca,'Xticklabel',{'08.01.2019', '01.09.2019','30.06.2020','31.12.2020'})
    xtickangle(45)
    set(gca,'fontsize',20)
    box on
    hold off
    switch model
        case 'QRA'
            saveas(gca, fullfile(fname, 'sub_daily_weight_Poland'), 'fig');
        case 'single'  
            saveas(gca, fullfile(fname, 'sub_daily_weight_Poland_single'), 'fig');
    end
    
    
    %%%%%%%% Comparison the distribution of daily weights: histogram %%%%%%
    
    %%%%%%%%%%%%%%%%%%%% Plots for risk minimization %%%%%%%%%%%%%%%%%%%%%%
    binRange = 0:0.07:1;
    h_05_quantile = histcounts(day_weight_05_quantile,binRange, 'Normalization', 'probability');
    h_05_expectiles = histcounts(day_weight_05_expectiles,binRange, 'Normalization', 'probability');
    h_05_ES = histcounts(day_weight_05_ES, binRange,'Normalization', 'probability');
    h_05_std = histcounts(day_weight_05_std,binRange, 'Normalization', 'probability');

    figure
    bb = bar(binRange(1:end-1), [h_05_quantile; h_05_expectiles; h_05_ES; h_05_std]');
    bb(1).FaceColor = [0.9290, 0.6940, 0.1250]; 
    bb(2).FaceColor = [0.4660, 0.6740, 0.1880];
    bb(3).FaceColor = 'm';
    bb(4).FaceColor = [0, 0.4470, 0.7410];
    legend('quantile', 'expectiles', 'ES', 'std')
    title('The distribution of daily weights for risk minimization and different risk measures')
    ylabel('p')
    set(gca,'fontsize',14)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    switch model
        case 'QRA'
            saveas(gca, fullfile(fname, 'dist_risk_min_weight_Poland'), 'fig');
        case 'single'  
            saveas(gca, fullfile(fname, 'dist_risk_min_weight_Poland_single'), 'fig');
    end

    %%%%%%%%%%%%%%%%%%%%%%% Plots for optimal strategy %%%%%%%%%%%%%%%%%%%%
    
    binRange = 0:0.03:1;
    h_05_sharpe = histcounts(day_weight_05_sharpe,binRange, 'Normalization', 'probability');
    h_05_q_50_IQR = histcounts(day_weight_05_q_50_IQR,binRange, 'Normalization', 'probability');
    
    figure
    b = bar(binRange(1:end-1), [h_05_sharpe; h_05_q_50_IQR]');
    b(1).FaceColor = 'm';
    b(2).FaceColor = [0.4660, 0.6740, 0.1880];
    legend('sharpe ratio', 'q_{50}/IQR')
    title('The distribution of daily weights for optimal strategy and different risk measures')
    ylabel('p')
    set(gca,'fontsize',14)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    switch model
        case 'QRA'
            saveas(gca, fullfile(fname, 'dist_optimal_strategy_weight_Poland'), 'fig');
        case 'single'  
            saveas(gca, fullfile(fname, 'dist_optimal_strategy_weight_Poland_single'), 'fig');
    end  

    %%%%%%%%%%%%%%%%%%%%%%% Plots for profit maximization %%%%%%%%%%%%%%%%%

    binRange = 0:0.07:1;
    h_95_quantile = histcounts(day_weight_95_quantile,binRange, 'Normalization', 'probability');
    h_95_expectiles = histcounts(day_weight_95_expectiles,binRange, 'Normalization', 'probability');
    h_95_mean = histcounts(day_weight_95_mean, binRange,'Normalization', 'probability');
    h_95_ES = histcounts(day_weight_95_ES,binRange, 'Normalization', 'probability');
    h_95_median = histcounts(day_weight_05_median,binRange,'Normalization', 'probability');
    
    figure
    bbb = bar(binRange(1:end-1), [h_95_quantile; h_95_expectiles; h_95_mean; h_95_ES; h_95_median]');
    bbb(1).FaceColor = [0, 0.4470, 0.7410];
    bbb(2).FaceColor = 'm';
    bbb(3).FaceColor = [0.9290, 0.6940, 0.1250];
    bbb(4).FaceColor = [0.4660, 0.6740, 0.1880];
    bbb(5).FaceColor = [0.8500, 0.3250, 0.0980];
    legend('quantile', 'expectiles', 'mean','ES', 'median')
    title('The distribution of daily weights for profit maximization and different risk measures')
    ylabel('p')
    set(gca,'fontsize',14)
    box on
    hold off
    set(gcf,'units','centimeters', 'Position',  [0, 0, 26, 10])
    switch model
        case 'QRA'
            saveas(gca, fullfile(fname, 'dist_max_weight_Poland'), 'fig'); 
        case 'single'  
            saveas(gca, fullfile(fname, 'dist_max_weight_Poland_single'), 'fig');
    end  
    
end